@@ -104,13 +104,14 @@ def search(request, search_id=0, group_id=0, opportunity_id=0):
     else:
         search = get_object_or_404(models.Search, id=search_id) if search_id else None
         search_form = forms.SearchForm(instance=search)
-        
+    
+    entities_count = len(entities)
     return render_to_response(
         'Search/search.html',
         {
             'request': request, 'entities': entities, 'nb_entities_by_page': getattr(settings, 'SANZA_SEARCH_NB_IN_PAGE', 50),
             'field_choice_form': field_choice_form, 'message': message, 'has_empty_entities': has_empty_entities,
-            'search_form': search_form, 'search': search, 'contacts_count': contacts_count,
+            'search_form': search_form, 'search': search, 'contacts_count': contacts_count, 'entities_count': entities_count,
             'contains_refuse_newsletter': contains_refuse_newsletter, 'group': group, 'opportunity': opportunity,
         },
         context_instance=RequestContext(request)
@@ -466,6 +467,7 @@ def contacts_admin(request):
 
 @user_passes_test(can_access)
 @popup_redirect
+@log_error
 def export_to_pdf(request):
     try:
         if request.method == "POST":
@@ -481,7 +483,16 @@ def export_to_pdf(request):
                         "search_dict": json.loads(form.cleaned_data['search_dict']),
                     }
                     
-                    pdf_view = PDFTemplateView(filename='sanza.pdf', template_name=template_name, request=request)
+                    context = form.patch_context(context)
+                    
+                    pdf_options = getattr(settings, 'SANZA_PDF_OPTIONS', {})
+                    cmd_options = pdf_options.get(template_name, {})
+                    
+                    pdf_view = PDFTemplateView(
+                        filename='sanza.pdf',
+                        template_name=template_name,
+                        request=request,
+                        cmd_options=cmd_options)
                     return pdf_view.render_to_response(context)
 
                 else:
